@@ -200,7 +200,8 @@ _LoadPNG(ImlibData * id, FILE * f, int *w, int *h, int *t)
   *h = hh;
 
   /* Setup Translators */
-  if (color_type == PNG_COLOR_TYPE_PALETTE)
+  if ((color_type == PNG_COLOR_TYPE_PALETTE) ||
+      (color_type == PNG_COLOR_TYPE_GRAY))
     png_set_expand(png_ptr);
   png_set_strip_16(png_ptr);
   png_set_packing(png_ptr);
@@ -273,6 +274,7 @@ _LoadPNG(ImlibData * id, FILE * f, int *w, int *h, int *t)
 	  for (x = 0; x < *w; x++)
 	    {
 	      r = *ptr2++;
+              ptr2++;
 	      *ptr++ = r;
 	      *ptr++ = r;
 	      *ptr++ = r;
