@@ -59,7 +59,8 @@ loader_png (FILE * f, int *w, int *h, int *t)
   *w = ww;
   *h = hh;
   /* Setup Translators */
-  if (color_type == PNG_COLOR_TYPE_PALETTE)
+  if ((color_type == PNG_COLOR_TYPE_PALETTE) ||
+      (color_type == PNG_COLOR_TYPE_GRAY))
     png_set_expand(png_ptr);
   png_set_strip_16(png_ptr);
   png_set_packing(png_ptr);
@@ -130,6 +131,7 @@ loader_png (FILE * f, int *w, int *h, int *t)
 	  for (x = 0; x < *w; x++)
 	    {
 	      r = *ptr2++;
+              ptr2++;
 	      *ptr++ = r;
 	      *ptr++ = r;
 	      *ptr++ = r;
